import { $cause, $meta, $namespace, $tags } from './symbols.js';
import type { JsonObject } from 'type-fest';
import type { RenderOptions } from './render.js';
export interface XceptionOptions {
    /** upstream error */
    cause?: unknown;
    /** error namespace */
    namespace?: string;
    /** context where the error occur */
    meta?: Record<string, unknown>;
    /** additional associations for the error */
    tags?: string[];
}
/** a high-order error that combine previous stack and tags */
export declare class Xception extends Error {
    /** upstream error */
    protected [$cause]?: unknown;
    /** error namespace */
    protected [$namespace]?: string;
    /** running context */
    protected [$meta]: Record<string, unknown>;
    /** additional associations */
    protected [$tags]: string[];
    /**
     * @param message error message
     * @param options additional options for the error
     */
    constructor(message: string, options?: XceptionOptions);
    /**
     * get the upstream error
     */
    get cause(): unknown;
    /**
     * get the error namespace
     */
    get namespace(): string | undefined;
    /**
     * get the running context
     */
    get meta(): Record<string, unknown>;
    /**
     * get the additional associations
     */
    get tags(): string[];
    /**
     * render the error to a string
     * @param options optional parameters
     * @returns a rendered string to print
     */
    render(options?: RenderOptions): string;
    /**
     * convert the error to a jsonifiable object
     * @returns a jsonifiable object
     */
    toJSON(): JsonObject;
}
//# sourceMappingURL=base.d.ts.map