import type { StackLocationBlock } from './stack.js';
/** options for rendering an error */
export interface RenderOptions {
    /** indent for each line */
    indent?: string;
    /** indicate whether a source frame should be shown */
    showSource?: boolean;
    /** indicate whether the full stack should be shown */
    showStack?: boolean;
    /** a filter function determining whether a stack should be shown given the file path */
    filter?: (path: string) => boolean;
}
/**
 * render an error in a human readable format
 * @param error the error to be rendered
 * @param options optional parameters
 * @returns a string representation of the error
 */
export declare function renderError(error: Error, options?: RenderOptions): string;
/**
 * render a location line
 * @param block a stack block about a location
 * @param options optional parameters
 * @param options.indent indent for each line
 * @param options.showSource indicate whether a source frame should be shown
 * @returns a rendered string to print
 */
export declare function renderLocation(block: StackLocationBlock, options: {
    indent: string;
    showSource: boolean;
}): string;
//# sourceMappingURL=render.d.ts.map